@@ -52,11 +52,17 @@
 #' made with `grid::linearGradient()`/`grid::radialGradient()`/`grid::pattern()`
 #' @param border The color of the background stroke. The background includes
 #' the padding but not the margin
-#' @param border_size The line width of the background stroke, given as a call
+#' @param border_width The line width of the background stroke, given as a call
 #' to [trbl()]
+#' @param border_type The linetype of the background stroke, given as an an
+#' `lty` compatible value (See the *Line Type Specification* section in
+#' [par][graphics::par])
 #' @param border_radius The corner radius of the background, given in points
 #' @param outline The color of the outline stroke.
 #' @param outline_width The line width of the outline stroke.
+#' @param outline_type The linetype of the outline stroke, given as an an
+#' `lty` compatible value (See the *Line Type Specification* section in
+#' [par][graphics::par])
 #' @param outline_join The line join type for the outline. Either `"round"`,
 #' `"mitre"`, or `"bevel"`.
 #' @param outline_mitre The mitre limit (relative distance between inner and
@@ -75,6 +81,9 @@
 #' consequtive blocks of text are laid out left-to-right or right-to-left. It
 #' also affects to which side indentation is applied as well as the meaning of
 #' `"auto"`, and `"justified-auto"` aligment.
+#' @param border_size `r lifecycle::badge('deprecated')` Use `border_width`
+#' instead
+#'
 #'
 #' @return A `marquee_style` object
 #'
@@ -104,10 +113,12 @@ style <- function(
   padding = NULL,
   background = NULL,
   border = NULL,
-  border_size = NULL,
+  border_width = NULL,
+  border_type = NULL,
   border_radius = NULL,
   outline = NULL,
   outline_width = NULL,
+  outline_type = NULL,
   outline_join = NULL,
   outline_mitre = NULL,
   bullets = NULL,
@@ -115,7 +126,8 @@ style <- function(
   strikethrough = NULL,
   baseline = NULL,
   img_asp = NULL,
-  text_direction = NULL
+  text_direction = NULL,
+  border_size = deprecated()
 ) {
   check_string(family, allow_null = TRUE)
 
@@ -204,11 +216,36 @@ style <- function(
     border[] <- NA_character_
   }
 
-  if (is.null(border_size)) {
-    border_size <- trbl()
+  if (lifecycle::is_present(border_size)) {
+    lifecycle::deprecate_soft(
+      "1.1.2",
+      "style(border_size)",
+      "style(border_width)"
+    )
+    border_width <- border_size
   }
-  if (!is_trbl(border_size)) {
-    stop_input_type(border_size, "a marquee_trbl object", allow_null = TRUE)
+
+  if (is.null(border_width)) {
+    border_width <- trbl()
+  }
+  if (!is_trbl(border_width)) {
+    stop_input_type(border_width, "a marquee_trbl object", allow_null = TRUE)
+  }
+
+  if (!is.null(border_type)) {
+    if (is.character(border_type)) {
+      check_string(border_type)
+      if (
+        !border_type %in% linetype_names &&
+          nchar(border_type) %in% c(2, 4, 6, 8) &&
+          !grepl("^[a-fA-F0-9]{2,8}$", border_type)
+      ) {
+        stop_input_type(border_type, "a valid lty value", allow_null = TRUE)
+      }
+    } else {
+      check_number_whole(border_type, min = 1, max = 6)
+      border_type <- linetype_names[border_type + 1]
+    }
   }
 
   if (is.unit(border_radius)) {
@@ -227,6 +264,22 @@ style <- function(
     outline_width <- as_bigpts(outline_width)
   }
 
+  if (!is.null(outline_type)) {
+    if (is.character(outline_type)) {
+      check_string(outline_type)
+      if (
+        !outline_type %in% linetype_names &&
+          nchar(outline_type) %in% c(2, 4, 6, 8) &&
+          !grepl("^[a-fA-F0-9]+$", outline_type)
+      ) {
+        stop_input_type(outline_type, "a valid lty value", allow_null = TRUE)
+      }
+    } else {
+      check_number_whole(outline_type, min = 1, max = 6)
+      outline_type <- linetype_names[outline_type + 1]
+    }
+  }
+
   check_string(outline_join, allow_null = TRUE)
   if (!is.null(outline_join)) {
     outline_join <- arg_match0(outline_join, c("round", "mitre", "bevel"))
@@ -277,13 +330,15 @@ style <- function(
       padding_bottom = padding[[3]],
       padding_left = padding[[4]],
       border = border,
-      border_size_top = border_size[[1]],
-      border_size_right = border_size[[2]],
-      border_size_bottom = border_size[[3]],
-      border_size_left = border_size[[4]],
+      border_width_top = border_width[[1]],
+      border_width_right = border_width[[2]],
+      border_width_bottom = border_width[[3]],
+      border_width_left = border_width[[4]],
+      border_type = border_type,
       border_radius = border_radius,
       outline = outline,
       outline_width = outline_width,
+      outline_type = outline_type,
       outline_join = outline_join,
       outline_mitre = outline_mitre,
       bullets = bullets,
@@ -383,10 +438,12 @@ base_style <- function(
   padding = trbl(0),
   background = NA,
   border = NA,
-  border_size = trbl(0),
+  border_width = trbl(0),
+  border_type = "solid",
   border_radius = 0,
   outline = NA,
   outline_width = 1,
+  outline_type = "solid",
   outline_join = "round",
   outline_mitre = 10,
   bullets = marquee_bullets,
@@ -394,8 +451,17 @@ base_style <- function(
   strikethrough = FALSE,
   baseline = 0,
   img_asp = 1.65,
-  text_direction = "auto"
+  text_direction = "auto",
+  border_size = deprecated()
 ) {
+  if (lifecycle::is_present(border_size)) {
+    lifecycle::deprecate_soft(
+      "1.1.2",
+      "base_style(border_size)",
+      "base_style(border_width)"
+    )
+    border_width <- border_size
+  }
   style(
     family = family,
     weight = weight,
@@ -413,10 +479,12 @@ base_style <- function(
     padding = padding,
     background = background,
     border = border,
-    border_size = border_size,
+    border_width = border_width,
+    border_type = border_type,
     border_radius = border_radius,
     outline = outline,
     outline_width = outline_width,
+    outline_type = outline_type,
     outline_join = outline_join,
     outline_mitre = outline_mitre,
     bullets = bullets,
@@ -427,3 +495,13 @@ base_style <- function(
     text_direction = text_direction
   )
 }
+
+linetype_names <- c(
+  "blank",
+  "solid",
+  "dashed",
+  "dotted",
+  "dotdash",
+  "longdash",
+  "twodash"
+)
